<?PHP // $Id: moodle.php,v 1.141.2.83 2010/03/22 22:10:34 stronk7 Exp $
      // moodle.php - created with Moodle 1.7 beta + (2006101003)


$string['abouttobeinstalled'] = 'about to be installed';
$string['action'] = 'Action';
$string['actions'] = 'Actions';
$string['active'] = 'Active';
$string['activeusers'] = 'Active users';
$string['activities'] = 'Activities';
$string['activity'] = 'Activity';
$string['activityclipboard'] = 'Moving this activity: <b>$a</b>';
$string['activityiscurrentlyhidden'] = 'Sorry, this activity is currently hidden';
$string['activitymodule'] = 'Activity module';
$string['activityreport'] = 'Activity report';
$string['activityreports'] = 'Activity reports';
$string['activityselect'] = 'Select this activity to be moved elsewhere';
$string['activitysince'] = 'Activity since $a';
$string['activityweighted'] = 'Activity per user';
$string['add'] = 'Add';
$string['addactivity'] = 'Add an activity...';
$string['addadmin'] = 'Add admin';
$string['addcreator'] = 'Add course creator';
$string['added'] = 'Added $a';
$string['addedrecip'] = 'Added $a new recipient';
$string['addedrecips'] = 'Added $a new recipients';
$string['addedtogroup'] = 'Added to group \"$a\"';
$string['addedtogroupnot'] = 'Not added to group \"$a\"';
$string['addedtogroupnotenrolled'] = 'Not added to group \"$a\", because not enrolled in course';
$string['addinganew'] = 'Adding a new $a';
$string['addinganewto'] = 'Adding a new $a->what to $a->to';
$string['addingdatatoexisting'] = 'Adding data to existing';
$string['addnewcategory'] = 'Add new category';
$string['addnewcourse'] = 'Add a new course';
$string['addnewuser'] = 'Add a new user';
$string['addnousersrecip'] = 'Add users who haven\'t accessed this $a to recipient list';
$string['addresource'] = 'Add a resource...';
$string['address'] = 'Address';
$string['addstudent'] = 'Add student';
$string['addsubcategory'] = 'Add a sub-category';
$string['addteacher'] = 'Add teacher';
$string['admin'] = 'Admin';
$string['adminbookmarks'] = 'Admin bookmarks';
$string['adminhelpaddnewuser'] = 'To manually create a new user account';
$string['adminhelpassignadmins'] = 'Admins can do anything and go anywhere in the site';
$string['adminhelpassigncreators'] = 'Course creators can create new courses';
$string['adminhelpassignsiteroles'] = 'Apply defined site roles to specific users';
$string['adminhelpassignstudents'] = 'Go into a course and add students from the admin menu';
$string['adminhelpassignteachers'] = 'Find a course then use the icon to add teachers';
$string['adminhelpauthentication'] = 'You can use internal user accounts or external databases';
$string['adminhelpbackup'] = 'Configure automated backups and their schedule';
$string['adminhelpconfiguration'] = 'Configure how the site looks and works';
$string['adminhelpconfigvariables'] = 'Configure variables that affect general operation of the site';
$string['adminhelpcourses'] = 'Define courses and categories and assign people to them, edit pending courses';
$string['adminhelpeditorsettings'] = 'Define basic settings for HTML editor';
$string['adminhelpedituser'] = 'Browse the list of user accounts and edit any of them';
$string['adminhelpenrolments'] = 'Choose internal or external ways to control enrolments';
$string['adminhelpenvironment'] = 'Check how your server suits current and future installation requirements';
$string['adminhelpfailurelogs'] = 'Browse logs of failed logins';
$string['adminhelphealthcenter'] = 'Automatic detection of site problems';
$string['adminhelplanguage'] = 'For checking and editing the current language pack';
$string['adminhelplogs'] = 'Browse logs of all activity on this site';
$string['adminhelpmanageblocks'] = 'Manage installed blocks and their settings';
$string['adminhelpmanagedatabase'] = 'Access the database directly (be careful!)';
$string['adminhelpmanagefilters'] = 'Choose text filters and related settings';
$string['adminhelpmanagemodules'] = 'Manage installed modules and their settings';
$string['adminhelpmanageroles'] = 'Create and define roles that may be applied to users';
$string['adminhelpmymoodle'] = 'Configure the My Moodle blocks for users';
$string['adminhelpreports'] = 'Site level reports';
$string['adminhelpsitefiles'] = 'For publishing general files or uploading external backups';
$string['adminhelpsitesettings'] = 'Define how the front page of the site looks';
$string['adminhelpstickyblocks'] = 'Configure Moodle-wide sticky blocks';
$string['adminhelpthemes'] = 'Choose how the site looks (colours, fonts etc)';
$string['adminhelpuploadusers'] = 'Import new user accounts from a text file';
$string['adminhelpusers'] = 'Define your users and set up authentication';
$string['adminhelpxmldbeditor'] = 'Interface to edit the XMLDB files. Only for developers.';
$string['administration'] = 'Administration';
$string['administrationsite'] = 'Site Administration';
$string['administrator'] = 'Administrator';
$string['administratordescription'] = 'Administrators can usually do anything on the site, in all courses.';
$string['administrators'] = 'Administrators';
$string['administratorsall'] = 'All administrators';
$string['administratorsandteachers'] = 'Administrators and teachers';
$string['adminprimarynoedit'] = 'You may not change the primary admin\'s password';
$string['advanced'] = 'Advanced';
$string['advancedfilter'] = 'Advanced search';
$string['advancedsettings'] = 'Advanced settings';
$string['again'] = 'again';
$string['aimid'] = 'AIM ID';
$string['ajaxno'] = 'No: use basic web features';
$string['ajaxuse'] = 'AJAX and Javascript';
$string['ajaxyes'] = 'Yes: use advanced web features';
$string['all'] = 'All';
$string['allactions'] = 'All actions';
$string['allactivities'] = 'All activities';
$string['allchanges'] = 'All changes';
$string['alldays'] = 'All days';
$string['allfieldsrequired'] = 'All fields are required';
$string['allfiles'] = 'All files';
$string['allgroups'] = 'All groups';
$string['alllogs'] = 'All logs';
$string['allmods'] = 'All $a';
$string['allow'] = 'Allow';
$string['allowguests'] = 'This course allows guest users to enter';
$string['allowinternal'] = 'Allow internal methods as well';
$string['allownone'] = 'Allow none';
$string['allownot'] = 'Do not allow';
$string['allparticipants'] = 'All participants';
$string['allteachers'] = 'All teachers';
$string['alphabet'] = 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z';
$string['alphanumerical'] = 'Can only contain alphabetical letters or numbers';
$string['alreadyconfirmed'] = 'Registration has already been confirmed';
$string['always'] = 'Always';
$string['and'] = '$a->one and $a->two';
$string['answer'] = 'Answer';
$string['approve'] = 'Approve';
$string['areyousuretorestorethis'] = 'Do you want to continue?';
$string['areyousuretorestorethisinfo'] = 'Later in this process you will have a choice of adding this backup to an existing course or creating a completely new course.';
$string['asc'] = 'Ascending';
$string['assessment'] = 'Assessment';
$string['assignadmins'] = 'Assign admins';
$string['assigncreators'] = 'Assign creators';
$string['assignsiteroles'] = 'Assign site-wide roles';
$string['assignstudents'] = 'Enrol students';
$string['assignstudentsnote'] = 'Note: it may not be necessary to use this page, since it is possible for students to enrol themselves in this course.';
$string['assignstudentspass'] = 'All you may need to do is notify your students of the enrolment key for this course, which is currently set to: \'$a\'';
$string['assignteachers'] = 'Assign teachers';
$string['authentication'] = 'Authentication';
$string['authenticateduser'] = 'Authenticated user';
$string['authenticateduserdescription'] = 'All logged in users.';
$string['autosubscribe'] = 'Forum auto-subscribe';
$string['autosubscribeno'] = 'No: don\'t automatically subscribe me to forums';
$string['autosubscribeyes'] = 'Yes: when I post, subscribe me to that forum';
$string['availability'] = 'Availability';
$string['availablecourses'] = 'Available Courses';
$string['backtoparticipants'] = 'Back to participants list';
$string['back'] = 'Back';
$string['backtocourselisting'] = 'Back to course listing';
$string['backup'] = 'Backup';
$string['backupactivehelp'] = 'Choose whether or not to do automated backups.';
$string['backupcancelled'] = 'Backup Cancelled';
$string['backupcoursefileshelp'] = 'If enabled then course files will be included in automated backups';
$string['backupdate'] = 'Backup Date';
$string['backupdatenew'] = '&nbsp; $a->TAG is now $a->weekday, $a->mday $a->month $a->year<br />';
$string['backupdateold'] = '$a->TAG was $a->weekday, $a->mday $a->month $a->year';
$string['backupdaterecordtype'] = '<br />$a->recordtype - $a->recordname<br />';
$string['backupdetails'] = 'Backup Details';
$string['backupexecuteathelp'] = 'Choose what time automated backups should run at.';
$string['backupfailed'] = 'Some of your courses weren\'t saved!!';
$string['backupfilename'] = 'backup';
$string['backupfinished'] = 'Backup completed successfully';
$string['backupfromthissite'] = 'Backup was made on this site?';
$string['backupgradebookhistoryhelp'] = 'If enabled then gradebook history will be included in automated backups. Note that grade history must not be disabled in server settings (disablegradehistory) in order for this to work';
$string['backupincludemoduleshelp'] = 'Choose whether you want to include course modules, with or without user data, in automated backups';
$string['backupincludemoduleuserdatahelp'] = 'Choose whether you want to include module user data in automated backups.';
$string['backupkeephelp'] = 'How many recent backups for each course do you want to keep? (older ones will be deleted automatically)';
$string['backuplogdetailed'] = 'Detailed execution log';
$string['backuploglaststatus'] = 'Last execution log';
$string['backuplogshelp'] = 'If enabled, then course logs will be included in automated backups';
$string['backupmetacoursehelp'] = 'If enabled, then metacourse info (inherited enrolments) will be included in automated backups';
$string['backupnameformat'] = '%%Y%%m%%d-%%H%%M';
$string['backupmissinguserinfoperms'] = 'Note: This backup contains no user data. Exercise and Workshop activities will not be included in the backup, since these modules are not compatible with this type of backup.';
$string['backupnoneusersinfo'] = 'Note: This backup contains no users and so all activities have been switched to \"without user data\" mode. Exercise and Workshop activities will not be included in the backup, since these modules are not compatible with this type of backup.';
$string['backupnonisowarning'] = 'Warning: this backup is from a non-Unicode version of Moodle (pre 1.6).  If this backup contains any non-ISO-8859-1 texts then they may be CORRUPTED if you try to restore them to this Unicode version of Moodle.  See the <a href=\"http://docs.moodle.org/en/Backup_FAQ\">Backup FAQ</a> for more information about how to recover this backup correctly.';
$string['backupnext'] = 'Next backup';
$string['backuporiginalname'] = 'Backup Name';
$string['backuproleassignments'] = 'Backup role assignments for these roles';
$string['backupsavetohelp'] = 'Full path to the directory where you want to save the backup files<br />(leave blank to save in its course default dir)';
$string['backupschedulehelp'] = 'Choose which days of the week to perform automated backups.';
$string['backupsitefileshelp'] = 'If enabled then site files used in courses will be included in automated backups';
$string['backuptakealook'] = 'Please take a look at your backup logs in:
  $a';
$string['backupuserfileshelp'] = 'Choose whether user files (eg profile images) should be included in automated backups';
$string['backupusershelp'] = 'Select whether you want to include all the users in the server or only the needed users for each course';
$string['backupversion'] = 'Backup Version';
$string['block'] = 'Block';
$string['blockconfiga'] = 'Configuring a $a block';
$string['blockconfigbad'] = 'This block has not been implemented correctly and thus cannot provide a configuration interface.';
$string['blockdeleteconfirm'] = 'You are about to completely delete the block \'$a\'.  This will completely delete everything in the database associated with this block.  Are you SURE you want to continue?';
$string['blockdeletefiles'] = 'All data associated with the block \'$a->block\' has been deleted from the database.  To complete the deletion (and prevent the block re-installing itself), you should now delete this directory from your server: $a->directory';
$string['blocks'] = 'Blocks';
$string['blocksaddedit'] = 'Add/Edit Blocks';
$string['blockseditoff'] = 'Blocks editing off';
$string['blocksediton'] = 'Blocks editing on';
$string['blocksetup'] = 'Setting up block tables';
$string['blocksuccess'] = '$a tables have been set up correctly';
$string['bycourseorder'] = 'By course order';
$string['byname'] = 'by $a';
$string['bypassed'] = 'Bypassed';
$string['cachecontrols'] = 'Cache Controls';
$string['cancel'] = 'Cancel';
$string['cancelled'] = 'Cancelled';
$string['categories'] = 'Course categories';
$string['category'] = 'Category';
$string['categoryadded'] = 'The category \'$a\' was added';
$string['categorycurrentcontents'] = 'Contents of $a';
$string['categorycontents'] = 'Subcategories and courses';
$string['categorydeleted'] = 'The category \'$a\' was deleted';
$string['categoryduplicate'] = 'A category named \'$a\' already exists!';
$string['categorymodifiedcancel'] = 'Category was modified! Please cancel and try again.';
$string['categoryname'] = 'Category name';
$string['categoryupdated'] = 'The category \'$a\' was updated';
$string['changedpassword'] = 'Changed password';
$string['changepassword'] = 'Change password';
$string['changessaved'] = 'Changes saved';
$string['check'] = 'Check';
$string['checkall'] = 'Check all';
$string['checkingbackup'] = 'Checking backup';
$string['checkingcourse'] = 'Checking course';
$string['checkingforbbexport'] = 'Checking for BlackBoard export';
$string['checkinginstances'] = 'Checking instances';
$string['checkingsections'] = 'Checking sections';
$string['checklanguage'] = 'Check language';
$string['checknone'] = 'Check none';
$string['childcoursenotfound'] = 'Child course not found!';
$string['childcourses'] = 'Child courses';
$string['choose'] = 'Choose';
$string['choosecourse'] = 'Choose a course';
$string['chooseenrolmethod'] = 'Choose enrolment plugin';
$string['chooselivelogs'] = 'Or watch current activity';
$string['chooselogs'] = 'Choose which logs you want to see';
$string['choosereportfilter'] = 'Choose a filter for the report';
$string['choosetheme'] = 'Choose theme';
$string['chooseuser'] = 'Choose a user';
$string['city'] = 'City/town';
$string['clambroken'] = 'Your administrator has enabled virus checking for file uploads but has misconfigured something.<br />Your file upload was NOT successful. Your administrator has been emailed to notify them so they can fix it.<br />Maybe try uploading this file later.';
$string['clamdeletedfile'] = 'The file has been deleted';
$string['clamdeletedfilefailed'] = 'The file could not be deleted';
$string['clamemailsubject'] = '$a :: Clam AV notification';
$string['clamfailed'] = 'Clam AV has failed to run.  The return error message was $a. Here is the output from Clam:';
$string['clamlost'] = 'Moodle is configured to run clam on file upload, but the path supplied to Clam AV, $a,  is invalid.';
$string['clamlostandactinglikevirus'] = 'In addition, Moodle is configured so that if clam fails to run, files are treated like viruses.  This essentially means that no student can upload a file successfully until you fix this.';
$string['clammovedfile'] = 'The file has been moved to your specified quarantine directory, the new location is $a';
$string['clammovedfilebasic'] = 'The file has been moved to a quarantine directory.';
$string['clamquarantinedirfailed'] = 'Could not move the file into your specified quarantine directory, $a. You need to fix this as files are being deleted if they\'re found to be infected.';
$string['clamunknownerror'] = 'There was an unknown error with clam.';
$string['cleaningtempdata'] = 'Cleaning temp data';
$string['clicktochange'] = 'Click to change';
$string['clickhere'] = 'Click here ...';
$string['closewindow'] = 'Close this window';
$string['comparelanguage'] = 'Compare and edit current language';
$string['complete'] = 'Complete';
$string['completereport'] = 'Complete report';
$string['configuration'] = 'Configuration';
$string['confirm'] = 'Confirm';
$string['confirmcheckfull'] = 'Are you absolutely sure you want to confirm $a ?';
$string['confirmed'] = 'Your registration has been confirmed';
$string['confirmednot'] = 'Your registration has not yet been confirmed!';
$string['continue'] = 'Continue';
$string['continuetocourse'] = 'Click here to enter your course';
$string['convertingwikitomarkdown'] = 'Converting Wiki to Markdown';
$string['cookiesenabled'] = 'Cookies must be enabled in your browser';
$string['cookiesnotenabled'] = 'Unfortunately, cookies are currently not enabled in your browser';
$string['copy'] = 'copy';
$string['copyasnoun'] = 'copy';
$string['copyingcoursefiles'] = 'Copying course files';
$string['copyingsitefiles'] = 'Copying site files used in course';
$string['copyinguserfiles'] = 'Copying user files';
$string['copyingzipfile'] = 'Copying zip file';
$string['copyrightnotice'] = 'Copyright notice';
$string['coresystem'] = 'System';
$string['cost'] = 'Cost';
$string['costdefault'] = 'Default cost';
$string['counteditems'] = '$a->count $a->items';
$string['country'] = 'Country';
$string['course'] = 'Course';
$string['courseapprovedemail'] = 'Your requested course, $a->name, has been approved and you have been made a $a->teacher.  To access your new course, go to $a->url';
$string['courseapprovedfailed'] = 'Failed to save the course as approved!';
$string['courseapprovedsubject'] = 'Your course has been approved!';
$string['courseavailable'] = 'This course is available to students';
$string['courseavailablenot'] = 'This course is not available to students';
$string['coursebackup'] = 'Course backup';
$string['coursecategories'] = 'Course categories';
$string['coursecategory'] = 'Course category';
$string['coursecategorydeleted'] = 'Deleted course category $a';
$string['coursecreators'] = 'Course creator';
$string['coursecreatorsdescription'] = 'Course creators can create new courses.';
$string['coursedeleted'] = 'Deleted course $a';
$string['coursefiles'] = 'Course files';
$string['courseformatdata'] = 'Course format data';
$string['courseformats'] = 'Course formats';
$string['coursegrades'] = 'Course grades';
$string['coursehelpcategory'] = 'Position the course on the course listing and may make it easier for students to find it.';
$string['coursehelpformat'] = 'The course main page will be displayed in this format.';
$string['coursehelpnumberweeks'] = 'Number of weeks/topics displayed on the course main page.';
$string['coursehelphiddensections'] = 'How the hidden sections in the course are displayed to students.';
$string['coursehelpnewsitemsnumber'] = 'Number of recent items appearing on the course home page, in a news box down the right-hand side <br/>(0 means the news box won\'t appear)
.';
$string['coursehelpshowgrades'] = 'Enable the display of the gradebook. It does not prevent grades from being displayed within the individual activities.';
$string['coursehelpmaximumupload'] = 'Define the largest size of file that can be uploaded in this course, limited by the site-wide setting.';
$string['coursehelpmetacourse'] = 'Set the course a metacourse. A meta course takes enrolments (and other role assignments) from a \"child\" course or courses.';
$string['coursehidden'] = 'This course is currently unavailable to students';
$string['courseimportnotaught'] = 'You don\'t seem to be an editing teacher in any other courses, there are no courses for you to import from.';
$string['courseinfo'] = 'Course info';
$string['coursemessage'] = 'Message course users';
$string['coursenotaccessible'] = 'This course does not allow public access';
$string['courseoverview'] = 'Course overview';
$string['courseoverviewgraph'] = 'Course overview graph';
$string['coursereasonforrejecting'] = 'Your reasons for rejecting this request';
$string['coursereasonforrejectingemail'] = 'This will be emailed to the requester';
$string['coursereject'] = 'Reject a course request';
$string['courserejected'] = 'Course has been rejected and the requester has been notified.';
$string['courserejectemail'] = 'Sorry, but the course you requested has been rejected. Here is the reason provided:

$a';
$string['courserejectreason'] = 'Outline your reasons for rejecting this course<br />(this will be emailed to the requester)';
$string['courserejectsubject'] = 'Your course has been rejected';
$string['coursereports'] = 'Course reports';
$string['courserequest'] = 'Course request';
$string['courserequestdetails'] = 'Details of the course you are requesting';
$string['courserequestdisabled'] = 'Sorry, but requesting courses has been disabled by the administrator';
$string['courserequestfailed'] = 'For some reason, your course request could not be saved';
$string['courserequestintro'] = 'Use this form to request a course to be created for you.<br />Try and fill in as much information as you can to allow<br />the administrators to understand your reasons for wanting this course.';
$string['courserequestreason'] = 'Reasons for wanting this course';
$string['courserequestsuccess'] = 'Successfully saved your course request. Expect an email within a few days with the outcome';
$string['courserequestsupport'] = 'Supporting information to help the administrator evaluate this request';
$string['courserestore'] = 'Course restore';
$string['courses'] = 'Courses';
$string['coursescategory'] = 'Courses in the same category';
$string['coursesettings'] = 'Course default settings';
$string['coursesmovedout'] = 'Courses moved out from $a';
$string['coursespending'] = 'Courses pending approval';
$string['coursestaught'] = 'Courses I have taught';
$string['courseupdates'] = 'Course updates';
$string['courseuploadlimit'] = 'Course upload limit';
$string['create'] = 'Create';
$string['createaccount'] = 'Create my new account';
$string['createcategory'] = 'Create category';
$string['createfolder'] = 'Create a folder in $a';
$string['createuserandpass'] = 'Choose your username and password';
$string['createziparchive'] = 'Create zip archive';
$string['creatingblocks'] = 'Creating blocks';
$string['creatingblogsinfo'] = 'Creating blogs info';
$string['creatingblocksroles'] = 'Creating block level role assignments and overrides';
$string['creatingcategoriesandquestions'] = 'Creating categories and questions';
$string['creatingcoursemodules'] = 'Creating course modules';
$string['creatingcourseroles'] = 'Creating course level role assignments and overrides';
$string['creatingevents'] = 'Creating events';
$string['creatinggradebook'] = 'Creating gradebook';
$string['creatinggroups'] = 'Creating groups';
$string['creatinggroupings'] = 'Creating groupings';
$string['creatinggroupingsgroups'] = 'Adding groups into groupings';
$string['creatinglogentries'] = 'Creating log entries';
$string['creatingmessagesinfo'] = 'Creating messages info';
$string['creatingmetacoursedata'] = 'Creating metacourse info';
$string['creatingmodroles'] = 'Creating module level role assignments and overrides';
$string['creatingnewcourse'] = 'Creating new course';
$string['creatingrolesdefinitions'] = 'Creating roles definitions';
$string['creatingscales'] = 'Creating scales';
$string['creatingsections'] = 'Creating sections';
$string['creatingtemporarystructures'] = 'Creating temporary structures';
$string['creatinguserroles'] = 'Creating user level role assignments and overrides';
$string['creatingusers'] = 'Creating users';
$string['creatingxmlfile'] = 'Creating XML file';
$string['currency'] = 'Currency';
$string['currentcourseadding'] = 'Current course, adding data to it';
$string['currentcoursedeleting'] = 'Current course, deleting it first';
$string['currentlanguage'] = 'Current language';
$string['currentlocaltime'] = 'your current local time';
$string['currentlyselectedusers'] = 'Currently selected users';
$string['currentpicture'] = 'Current picture';
$string['currentrelease'] = 'Current release information';
$string['currentversion'] = 'Current version';
$string['databasechecking'] = 'Upgrading Moodle database from version $a->oldversion to $a->newversion...';
$string['databaseperformance'] = 'Database performance';
$string['databasesetup'] = 'Setting up database';
$string['databasesuccess'] = 'Database was successfully upgraded';
$string['databaseupgradebackups'] = 'Backup version is now $a';
$string['databaseupgradeblocks'] = 'Blocks version is now $a';
$string['databaseupgradegroups'] = 'Groups version is now $a';
$string['databaseupgradelocal'] = 'Local database customisations version is now $a';
$string['databaseupgrades'] = 'Upgrading database';
$string['date'] = 'Date';
$string['datechanged'] = 'Date changed';
$string['datemostrecentfirst'] = 'Date - most recent first';
$string['datemostrecentlast'] = 'Date - most recent last';
$string['day'] = 'day';
$string['days'] = 'days';
$string['decodinginternallinks'] = 'Decoding internal links';
$string['default'] = 'Default';
$string['defaultcoursefullname'] = 'Course Fullname 101';
$string['defaultcourseshortname'] = 'CF101';
$string['defaultcoursestudent'] = 'Student';
$string['defaultcoursestudentdescription'] = 'Students generally have fewer privileges within a course.';
$string['defaultcoursestudents'] = 'Students';
$string['defaultcoursesummary'] = 'Write a concise and interesting paragraph here that explains what this course is about';
$string['defaultcourseteacher'] = 'Teacher';
$string['defaultcourseteacherdescription'] = 'Teachers can do anything within a course, including changing the activities and grading students.';
$string['defaultcourseteachers'] = 'Teachers';
$string['delete'] = 'Delete';
$string['deleteall'] = 'Delete all';
$string['deleteallcannotundo'] = 'Delete all - cannot be undone';
$string['deleteallcomments'] = 'Delete all comments';
$string['deleteallratings'] = 'Delete all ratings';
$string['deletecategory'] = 'Delete category: $a';
$string['deletecategorycheck'] = 'Are you absolutely sure you want to completely delete this category <b>\'$a\'</b>?<br />This will move all courses into the parent category if there is one, or into Miscellaneous.';
$string['deletecategorycheck2'] = 'If you delete this category, you need to choose what to do with the courses and subcategories it contains.';
$string['deletecategoryempty'] = 'This category is empty.';
$string['deletecheck'] = 'Delete $a ?';
$string['deletecheckfiles'] = 'Are you absolutely sure you want to delete these files?';
$string['deletecheckfull'] = 'Are you absolutely sure you want to completely delete $a ?';
$string['deletecheckwarning'] = 'You are about to delete these files';
$string['deletecompletely'] = 'Delete completely';
$string['deletecourse'] = 'Delete a course';
$string['deletecoursecheck'] = 'Are you absolutely sure you want to completely delete this course and all the data it contains?';
$string['deleted'] = 'Deleted';
$string['deletedactivity'] = 'Deleted $a';
$string['deletedcourse'] = '$a has been completely deleted';
$string['deletednot'] = 'Could not delete $a !';
$string['deletelogs'] = 'Delete logs';
$string['deleteselected'] = 'Delete selected';
$string['deleteselectedkey'] = 'Delete selected key';
$string['deletingcourse'] = 'Deleting $a';
$string['deletingexistingcoursedata'] = 'Deleting existing course data';
$string['deletingolddata'] = 'Deleting old data';
$string['department'] = 'Department';
$string['desc'] = 'Descending';
$string['description'] = 'Description';
$string['deselectall'] = 'Deselect all';
$string['detailedless'] = 'Less detailed';
$string['detailedmore'] = 'More detailed';
$string['directory'] = 'Directory';
$string['directorypaths'] = 'Directory Paths';
$string['disable'] = 'Disable';
$string['displayingfirst'] = 'Only the first $a->count $a->things are displayed';
$string['displayingrecords'] = 'Displaying $a records';
$string['displayingusers'] = 'Displaying users $a->start to $a->end';
$string['displayonpage'] = 'Display on page';
$string['documentation'] = 'Moodle Documentation';
$string['donotask'] = 'Do Not Ask';
$string['donotclickcontinue'] = 'Do not click on the following continue link ;-)';
$string['down'] = 'Down';
$string['downloadexcel'] = 'Download in Excel format';
$string['downloadods'] = 'Download in ODS format';
$string['downloadtext'] = 'Download in text format';
$string['doyouagree'] = 'Have you read these conditions and understood them?';
$string['duplicate'] = 'Duplicate';
$string['duplicatinga'] = 'Duplicating: $a';
$string['duplicatingain'] = 'Duplicating $a->what in $a->in';
$string['edhelpaspellpath'] = 'To use spell-checking within the editor, you MUST have <strong>aspell 0.50</strong> or later installed on your server, and you must specify the correct path to access the aspell binary.  On Unix/Linux systems, this path is usually <strong>/usr/bin/aspell</strong>, but it might be something else.';
$string['edhelpbgcolor'] = 'Define the edit area\'s background color.<br />Valid values are, for example: #FFFFFF or white';
$string['edhelpcleanword'] = 'This setting enables or disables Word-specific format filtering.';
$string['edhelpenablespelling'] = 'Enable or disable spell-checking. When enabled, <strong>aspell</strong> must be installed on the server. The second value is the <strong>default dictionary</strong>. This value will be used if aspell doesn\'t have dictionary for users own language.';
$string['edhelpfontfamily'] = 'The font-family property is a list of font family names and/or generic family names. Family names must be seperated with comma.';
$string['edhelpfontlist'] = 'Define the fonts used on editors dropdown menu.';
$string['edhelpfontsize'] = 'The default font-size sets the size of a font. <br />Valid values are for example: medium, large, smaller, larger, 10pt, 11px.';
$string['edit'] = 'Edit $a';
$string['editcategorysettings'] = 'Edit category settings';
$string['editcategorythis'] = 'Edit this category';
$string['editcoursesettings'] = 'Edit course settings';
$string['editfiles'] = 'Edit files';
$string['editgroupprofile'] = 'Edit group profile';
$string['editinga'] = 'Editing $a';
$string['editingteachershort'] = 'Editor';
$string['editlock'] = 'This value cannot be edited!';
$string['editmyprofile'] = 'Edit profile';
$string['editorbgcolor'] = 'Background-color';
$string['editorcleanonpaste'] = 'Clean Word HTML on paste';
$string['editorcommonsettings'] = 'Common settings';
$string['editordefaultfont'] = 'Default font';
$string['editorenablespelling'] = 'Enable spellchecking';
$string['editorfontlist'] = 'Fontlist';
$string['editorfontsize'] = 'Default font-size';
$string['editorhelptopics'] = 'Editor Help Topics.';
$string['editorresettodefaults'] = 'Reset to default values';
$string['editorsettings'] = 'Editor settings';
$string['editorshortcutkeys'] = 'Editor shortcut keys';
$string['editremoteprofile'] = 'Edit remote profile';
$string['editsummary'] = 'Edit summary';
$string['editthisactivity'] = 'Edit this activity';
$string['editthiscategory'] = 'Edit this category';
$string['edituser'] = 'Edit user accounts';
$string['email'] = 'Email address';
$string['emailactive'] = 'Email activated';
$string['emailagain'] = 'Email (again)';
$string['emailcharset'] = 'Email charset';
$string['emailconfirm'] = 'Confirm your account';
$string['emailconfirmation'] = 'Hi $a->firstname,

A new account has been requested at \'$a->sitename\'
using your email address.

To confirm your new account, please go to this web address:

$a->link

In most mail programs, this should appear as a blue link
which you can just click on.  If that doesn\'t work,
then cut and paste the address into the address
line at the top of your web browser window.

If you need help, please contact the site administrator,
$a->admin';
$string['emailconfirmationsubject'] = '$a: account confirmation';
$string['emailconfirmsent'] = '<p>An email should have been sent to your address at <b>$a</b></p>
   <p>It contains easy instructions to complete your registration.</p>
   <p>If you continue to have difficulty, contact the site administrator.</p>';
$string['emaildigest'] = 'Email digest type';
$string['emaildigestcomplete'] = 'Complete (daily email with full posts)';
$string['emaildigestoff'] = 'No digest (single email per forum post)';
$string['emaildigestsubjects'] = 'Subjects (daily email with subjects only)';
$string['emaildisable'] = 'This email address is disabled';
$string['emaildisableclick'] = 'Click here to disable all email from being sent to this address';
$string['emaildisplay'] = 'Email display';
$string['emaildisplaycourse'] = 'Allow only other course members to see my email address';
$string['emaildisplayno'] = 'Hide my email address from everyone';
$string['emaildisplayyes'] = 'Allow everyone to see my email address';
$string['emailenable'] = 'This email address is enabled';
$string['emailenableclick'] = 'Click here to re-enable all email being sent to this address';
$string['emailexists'] = 'This email address is already registered.';
$string['emailformat'] = 'Email format';
$string['emailmustbereal'] = 'Note: your email address must be a real one';
$string['emailnotallowed'] = 'Email addresses in these domains are not allowed ($a)';
$string['emailnotfound'] = 'The email address was not found in the database';
$string['emailonlyallowed'] = 'This email is not one of those that are allowed ($a)';
$string['emailpasswordconfirmation'] = 'Hi $a->firstname,

Someone (probably you) has requested a new password for your
account on \'$a->sitename\'.

To confirm this and have a new password sent to you via email,
go to the following web address:

$a->link

In most mail programs, this should appear as a blue link
which you can just click on.  If that doesn\'t work,
then cut and paste the address into the address
line at the top of your web browser window.

If you need help, please contact the site administrator,
$a->admin';
$string['emailpasswordconfirmationsubject'] = '$a: Change password confirmation';
$string['emailpasswordconfirmmaybesent'] = '<p>If you supplied a correct username or email address then an email should have been sent to you.</p>
   <p>It contains easy instructions to confirm and complete this password change.
If you continue to have difficulty, please contact the site administrator.</p>';
$string['emailpasswordconfirmsent'] = 'An email should have been sent to your address at <b>$a</b>.
<br />It contains easy instructions to confirm and complete this password change.
If you continue to have difficulty, contact the site administrator.';
$string['emailpasswordchangeinfo'] = 'Hi $a->firstname,

Someone (probably you) has requested a new password for your
account on \'$a->sitename\'.

To change your password, please go to the following web address:

$a->link

In most mail programs, this should appear as a blue link
which you can just click on.  If that doesn\'t work,
then cut and paste the address into the address
line at the top of your web browser window.

If you need help, please contact the site administrator,
$a->admin';
$string['emailpasswordchangeinfodisabled'] = 'Hi $a->firstname,

Someone (probably you) has requested a new password for your
account on \'$a->sitename\'.

Unfortunately your account on this site is disabled and can not be reset,
please contact the site administrator,
$a->admin';
$string['emailpasswordchangeinfofail'] = 'Hi $a->firstname,

Someone (probably you) has requested a new password for your
account on \'$a->sitename\'.

Unfortunately passwords can not be reset on this site,
please contact the site administrator,
$a->admin';
$string['emailpasswordchangeinfosubject'] = '$a: Change password information';
$string['emailpasswordsent'] = 'Thank you for confirming the change of password.
An email containing your new password has been sent to your address at<br /><b>$a->email</b>.<br />
The new password was automatically generated - you might like to
<a href=\"$a->link\">change your password</a> to something easier to remember.';
$string['enable'] = 'Enable';
$string['encryptedcode'] = 'Encrypted code';
$string['enroldate'] = 'Date range';
$string['enrolenddate'] = 'End date';
$string['enrolenddaterror'] = 'Enrolment end date cannot be earlier than start date';
$string['enrollable'] = 'Course enrollable';
$string['enrolledincourse'] = 'Enrolled in course \"$a\"';
$string['enrolledincourserole'] = 'Enrolled in \"$a->course\" as \"$a->role\"';
$string['enrolledincoursenot'] = 'Not enrolled in course \"$a\"';
$string['enrolledincoursenotrole'] = 'Error enrolling into \"$a->course\" as \"$a->role\"';
$string['enrollfirst'] = 'You have to enrol in one of the courses before you can use the site activities';
$string['enrolme'] = 'Enrol me in this course';
$string['enrolmentconfirmation'] = 'You are about to enrol yourself as a member of this course.<br />Are you sure you wish to do this?';
$string['enrolmentend'] = 'Enrolment Ends';
$string['enrolmentkey'] = 'Enrolment key';
$string['enrolmentkeyfrom'] = 'This course requires an \'enrolment key\' - a one-time<br />
password that you should have received from $a';
$string['enrolmentkeyfromguest'] = 'This course requires an \'enrolment key\' - as a guest<br />
you must enter it each time you enter the course. You should have received it from $a';
$string['enrolmentkeyhint'] = 'That enrolment key was incorrect, please try again<br />
(Here\'s a hint - it starts with \'$a\')';
$string['enrolmentnew'] = 'New enrolment in $a';
$string['enrolmentnewuser'] = '$a->user has enrolled in course \"$a->course\"';
$string['enrolmentnointernal'] = 'Manual enrolments are currently not enabled';
$string['enrolmentnotyet'] = 'Sorry, you can not access this course until <br /> $a';
$string['enrolmentplugins'] = 'Enrolment Plugins';
$string['enrolments'] = 'Enrolments';
$string['enrolmentstart'] = 'Enrolment Started';
$string['enrolperiod'] = 'Enrolment duration';
$string['enrolstartdate'] = 'Start date';
$string['entercourse'] = 'Click to enter this course';
$string['enteremailaddress'] = 'Enter in your email address to reset your
   password and have the new password sent to you via email.';
$string['entries'] = 'Entries';
$string['error'] = 'Error';
$string['errortoomanylogins'] = 'Sorry, you have exceeded the allowed number of login attempts. Restart your browser.';
$string['errorwhenconfirming'] = 'You are not confirmed yet because an error occurred.  If you clicked on a link in an email to get here, make sure that the line in your email wasn\'t broken or wrapped. You may have to use cut and paste to reconstruct the link properly.';
$string['everybody'] = 'Everybody';
$string['executeat'] = 'Execute at';
$string['existing'] = 'Existing';
$string['existingadmins'] = 'Existing admins';
$string['existingcourse'] = 'Existing course';
$string['existingcourseadding'] = 'Existing course, adding data to it';
$string['existingcoursedeleting'] = 'Existing course, deleting it first';
$string['existingcreators'] = 'Existing course creators';
$string['existingstudents'] = 'Enrolled students';
$string['existingteachers'] = 'Existing teachers';
$string['expirynotify'] = 'Enrolment expiry notification';
$string['expirynotifyemail'] = 'The following students in this course are expiring after exactly $a->threshold days:

$a->current

The following students in this course are expiring in less than $a->threshold days:

$a->past

You may go to the following page to extend their enrolment period:
$a->extendurl';
$string['expirynotifystudents'] = 'Notify students';
$string['expirynotifystudentsemail'] = 'Dear $a->studentstr:

This is a notification that your enrolment in the course $a->course will expire in $a->threshold days.

Please contact $a->teacherstr for any further enquiries.';
$string['expirythreshold'] = 'Threshold';
$string['explanation'] = 'Explanation';
$string['extendenrol'] = 'Extend enrolment (individual)';
$string['groupextendenrol'] = 'Extend enrolment (common)';
$string['courseenrolstartdate'] = 'Course enrolment start date';
$string['courseenrolenddate'] = 'Course enrolment end date';
$string['startingfrom'] = 'Starting from';
$string['extendperiod'] = 'Extended period';
$string['failedloginattempts'] = '$a->attempts failed logins since your last login';
$string['failedloginattemptsall'] = '$a->attempts failed logins for $a->accounts accounts';
$string['feedback'] = 'Feedback';
$string['file'] = 'File';
$string['filemissing'] = '$a is missing';
$string['files'] = 'Files';
$string['filesfolders'] = 'Files/folders';
$string['filloutallfields'] = 'Please fill out all fields in this form';
$string['findmorecourses'] = 'Find more courses...';
$string['firstaccess'] = 'First access';
$string['firstdayofweek'] = '0';
$string['firstname'] = 'First name';
$string['firsttime'] = 'Is this your first time here?';
$string['flashlinkmessage'] = 'Please upgrade your Flash player now:';
$string['flashupgrademessage'] = " The Flash plugin is required to play this content, but the version you have is too old.\n\n  You may need to log out and log in back after upgrade.";
$string['folder'] = 'Folder';
$string['folderclosed'] = 'Closed folder';
$string['folderopened'] = 'Opened folder';
$string['followingoptional'] = 'The following items are optional';
$string['followingrequired'] = 'The following items are required';
$string['force'] = 'Force';
$string['forcedmode'] = 'forced mode';
$string['forcelanguage'] = 'Force language';
$string['forceno'] = 'Do not force';
$string['forcepasswordchange'] = 'Force password change';
$string['forcepasswordchangecheckfull'] = 'Are you absolutely sure you want to force a password change to $a ?';
$string['forcepasswordchangehelp'] = 'Prompt user to change it on their next login';
$string['forcepasswordchangenot'] = 'Could not force a password change to $a';
$string['forcepasswordchangenotice'] = 'You must change your password to proceed.';
$string['forcetheme'] = 'Force theme';
$string['forgotaccount'] = 'Lost password?';
$string['forgotten'] = 'Forgotten your username or password?';
$string['forgottenduplicate'] = 'The email address is shared by several accounts, please enter username instead';
$string['forgotteninvalidurl'] = 'Invalid password reset URL';
$string['format'] = 'Format';
$string['formathtml'] = 'HTML format';
$string['formatlams'] = 'LAMS course format';
$string['formatmarkdown'] = 'Markdown format';
$string['formatplain'] = 'Plain text format';
$string['formatscorm'] = 'SCORM format';
$string['formatsocial'] = 'Social format';
$string['formattext'] = 'Moodle auto-format';
$string['formattexttype'] = 'Formatting';
$string['formattopics'] = 'Topics format';
$string['formattopicscss'] = 'Topics format - CSS/No tables';
$string['formattopicsajax'] = 'Topics format - AJAX';
$string['formatweeks'] = 'Weekly format';
$string['formatweekscss'] = 'Weekly format - CSS/No tables';
$string['formatwiki'] = 'Wiki-like format';
$string['framesetinfo'] = 'This frameset document contains:';
$string['from'] = 'From';
$string['frontpagecategorycombo'] = 'Combo list';
$string['frontpagecategorynames'] = 'List of categories';
$string['frontpagecourselist'] = 'List of courses';
$string['frontpagedescription'] = 'Front Page Description';
$string['frontpagedescriptionhelp'] = 'This description of the site will be displayed on the front page.';
$string['frontpageformat'] = 'Front page format';
$string['frontpageformatloggedin'] = 'Front page format when logged in';
$string['frontpagenews'] = 'News items';
$string['frontpagetopiconly'] = 'Topic section';
$string['fulllistofcourses'] = 'All courses';
$string['fullname'] = 'Full name';
$string['fullnamedisplay'] = '$a->firstname $a->lastname';
$string['fullprofile'] = 'Full profile';
$string['fullsitename'] = 'Full site name';
$string['functiondisabled'] = 'That functionality is currently disabled';
$string['gd1'] = 'GD 1.x is installed';
$string['gd2'] = 'GD 2.x is installed';
$string['gdneed'] = 'GD must be installed to see this graph';
$string['gdnot'] = 'GD is not installed';
$string['general'] = 'General';
$string['gettheselogs'] = 'Get these logs';
$string['go'] = 'Go';
$string['gotoyourserver'] = '(Links back to your server)';
$string['gpl'] = 'Copyright (C) 1999 onwards  Martin Dougiamas  (http://moodle.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the Moodle License information page for full details:
http://docs.moodle.org/en/License';
$string['grade'] = 'Grade';
$string['grades'] = 'Grades';
$string['group'] = 'Group';
$string['groupadd'] = 'Add new group';
$string['groupaddusers'] = 'Add selected to group';
$string['groupfor'] = 'for group';
$string['groupinfo'] = 'Info about selected group';
$string['groupinfoedit'] = 'Edit group settings';
$string['groupinfomembers'] = 'Info about selected members';
$string['groupinfopeople'] = 'Info about selected people';
$string['groupmembers'] = 'Group members';
$string['groupmemberssee'] = 'See group members';
$string['groupmembersselected'] = 'Members of selected group';
$string['groupmode'] = 'Group mode';
$string['groupmodeforce'] = 'Force group mode';
$string['groupmy'] = 'My group';
$string['groupnonmembers'] = 'People not in a group';
$string['groupnotamember'] = 'Sorry, you are not a member of that group';
$string['grouprandomassign'] = 'Randomly assign all to groups';
$string['groupremove'] = 'Remove selected group';
$string['groupremovemembers'] = 'Remove selected members';
$string['groups'] = 'Groups';
$string['groupsnone'] = 'No groups';
$string['groupsseparate'] = 'Separate groups';
$string['groupsvisible'] = 'Visible groups';
$string['guest'] = 'Guest';
$string['guestdescription'] = 'Guests have minimal privileges and usually can not enter text anywhere.';
$string['guestskey'] = 'Allow guests who have the key';
$string['guestsno'] = 'Do not allow guests in';
$string['guestsnotallowed'] = 'Sorry, \'$a\' does not allow guests to enter.';
$string['guestsyes'] = 'Allow guests without the key';
$string['guestuser'] = 'Guest User';
$string['guestuserinfo'] = 'This user is a special user that allows read-only access to some courses.';
$string['healthcenter'] = 'Health Center';
$string['healthnoproblemsfound'] = 'There is no health problem found!';
$string['healthproblemsdetected'] = 'Health Problems Detected!';
$string['healthproblemsolution'] = 'Health Problem Solution';
$string['healthreturntomain'] = 'Continue';
$string['healthsolution'] = 'Solution';
$string['help'] = 'Help';
$string['helpemoticons'] = 'Use emoticons';
$string['helpformatting'] = 'About formatting text';
$string['helpinterestslist'] = 'Enter your interests separated by commas';
$string['helphtml'] = 'How to write html';
$string['helpindex'] = 'Index of all help files';
$string['helppicture'] = 'How to upload a picture';
$string['helpprefix'] = 'Help, $a';
$string['helpprefix2'] = 'Help with $a';
$string['helpquestions'] = 'Ask good questions';
$string['helpreading'] = 'Read carefully';
$string['helprichtext'] = 'About the HTML editor';
$string['helpsummaries'] = 'About these summaries';
$string['helptext'] = 'How to write text';
$string['helpwiththis'] = 'Help with this';
$string['helpwiki'] = 'How to write Wiki-like text';
$string['helpwriting'] = 'Write carefully';
$string['hiddenassign'] = 'Hidden assignment';
$string['hiddensections'] = 'Hidden sections';
$string['hiddensectionscollapsed'] = 'Hidden sections are shown in collapsed form';
$string['hiddensectionsinvisible'] = 'Hidden sections are completely invisible';
$string['hide'] = 'Hide';
$string['hideadvancedsettings'] = 'Hide advanced settings';
$string['hidepicture'] = 'Hide picture';
$string['hidesection'] = 'Hide section $a';
$string['hidesettings'] = 'Hide settings';
$string['hits'] = 'Hits';
$string['hitsoncourse'] = 'Hits on $a->coursename by $a->username';
$string['hitsoncoursetoday'] = 'Today\'s hits on $a->coursename by $a->username';
$string['home'] = 'Home';
$string['hour'] = 'hour';
$string['hours'] = 'hours';
$string['howtomakethemes'] = 'How to make new themes';
$string['htmleditor'] = 'Use HTML editor (some browsers only)';
$string['htmleditoravailable'] = 'The HTML editor is available';
$string['htmleditordisabled'] = 'You have disabled the HTML editor in your user profile';
$string['htmleditordisabledadmin'] = 'The administrator has disabled the HTML editor on this site';
$string['htmleditordisabledbrowser'] = 'The HTML editor is unavailable because your web browser is not compatible';
$string['htmlfilesonly'] = 'HTML files only';
$string['htmlformat'] = 'Pretty HTML format';
$string['icqnumber'] = 'ICQ number';
$string['idnumber'] = 'ID number';
$string['idnumbermod'] = 'ID number';
$string['idnumbercourse'] = 'Course ID number';
$string['idnumbertaken'] = 'This ID number is already taken';
$string['imagealt'] = 'Picture description';
$string['import'] = 'Import';
$string['importactivities'] = 'Import activities from another course';
$string['importdata'] = 'Import course data';
$string['importdataexported'] = 'Exported data from \'from\' course successfully.<br /> Continue to import into your \'to\' course.';
$string['importdatafinished'] = 'Import complete! Continue to your course';
$string['importdatafrom'] = 'Find a course to import data from:';
$string['importgroups'] = 'Import groups';
$string['importmetacoursenote'] = 'Use this form to add courses to your meta course (this will import the enrolments)';
$string['inactive'] = 'Inactive';
$string['include'] = 'Include';
$string['includeallusers'] = 'Include All Users';
$string['includecoursefiles'] = 'Include Course Files';
$string['includecourseusers'] = 'Include Course Users';
$string['included'] = 'Included';
$string['includelogentries'] = 'Include Log Entries';
$string['includemodules'] = 'Include Modules';
$string['includemoduleuserdata'] = 'Include module user data';
$string['includeneededusers'] = 'Include Needed Users';
$string['includenoneusers'] = 'Include No Users';
$string['includeroleassignments'] = 'Include role assignments';
$string['includesitefiles'] = 'Include Site Files Used in This Course';
$string['includeuserfiles'] = 'Include User Files';
$string['info'] = 'Information';
$string['institution'] = 'Institution';
$string['instudentview'] = 'in student view';
$string['interests'] = 'Interests';
$string['interestslist'] = 'List of interests';
$string['invalidemail'] = 'Invalid email address';
$string['invalidlogin'] = 'Invalid login, please try again';
$string['ip_address'] = 'IP Address';
$string['jump'] = 'Jump';
$string['jumpto'] = 'Jump to...';
$string['keep'] = 'Keep';
$string['keepsearching'] = 'Keep searching';
$string['langltr'] = 'Language direction left-to-right';
$string['langrtl'] = 'Language direction right-to-left';
$string['language'] = 'Language';
$string['languagegood'] = 'This language pack is up-to-date! :-)';
$string['lastaccess'] = 'Last access';
$string['lastedited'] = 'Last edited';
$string['lastlogin'] = 'Last Login';
$string['lastmodified'] = 'Last modified';
$string['lastname'] = 'Surname';
$string['lastyear'] = 'Last year';
$string['latestlanguagepack'] = 'Check for latest language pack on moodle.org';
$string['latestnews'] = 'Latest News';
$string['layouttable'] = 'Layout table';
$string['leavetokeep'] = 'Leave blank to keep current password';
$string['license'] = 'GPL License';
$string['liketologin'] = 'Would you like to log in now with a full user account?';
$string['list'] = 'List';
$string['listfiles'] = 'List of files in $a';
$string['listofallpeople'] = 'List of all people';
$string['livelogs'] = 'Live logs from the past hour';
$string['local'] = 'Local';
$string['locale'] = 'en_AU.UTF-8';
$string['location'] = 'Location';
$string['log_excel_date_format'] = 'yyyy mmmm d h:mm';
$string['loggedinas'] = 'You are logged in as $a';
$string['loggedinasguest'] = 'You are currently using guest access';
$string['loggedinnot'] = 'You are not logged in.';
$string['login'] = 'Login';
$string['login_failure_logs'] = 'Login failure logs';
$string['loginalready'] = 'You are already logged in';
$string['loginas'] = 'Login as';
$string['loginaspasswordexplain'] = '<p>You must enter the special \"loginas password\" to use this feature.<br />If you do not know it, ask your server administrator.</p>';
$string['loginguest'] = 'Login as a guest';
$string['loginsite'] = 'Login to the site';
$string['loginsteps'] = 'Hi! For full access to courses you\'ll need to take
   a minute to create a new account for yourself on this web site.
   Each of the individual courses may also have a one-time
   \"enrolment key\", which you won\'t need until later. Here are
   the steps:
   <ol>
   <li>Fill out the <a href=\"$a\">New Account</a> form with your details.</li>
   <li>An email will be immediately sent to your email address.</li>
   <li>Read your email, and click on the web link it contains.</li>
   <li>Your account will be confirmed and you will be logged in.</li>
   <li>Now, select the course you want to participate in.</li>
   <li>If you are prompted for an \"enrolment key\" - use the one
   that your teacher has given you. This will \"enrol\" you in the
   course.</li>
   <li>You can now access the full course. From now on you will only need
   to enter your personal username and password (in the form on this page)
   to log in and access any course you have enrolled in.</li>
   </ol>';
$string['loginstepsnone'] = '<p>Hi!</p>
<p>For full access to courses you\'ll need to create yourself an account.</p>
<p>All you need to do is make up a username and password and use it in the form on this page!</p>
<p>If someone else has already chosen your username then you\'ll have to try again using a different username.</p>';
$string['loginto'] = 'Login to $a';
$string['loginusing'] = 'Login here using your username and password';
$string['logout'] = 'Logout';
$string['logoutconfirm'] = 'Do you really want to logout?';
$string['logs'] = 'Logs';
$string['logtoomanycourses'] = '[ <a href=\"$a->url\">more</a> ]';
$string['logtoomanyusers'] = '[ <a href=\"$a->url\">more</a> ]';
$string['lookback'] = 'Look back';
$string['mailadmins'] = 'Inform admins';
$string['mailstudents'] = 'Inform students';
$string['mailteachers'] = 'Inform teachers';
$string['mainmenu'] = 'Main Menu';
$string['makeafolder'] = 'Make a folder';
$string['makeeditable'] = 'If you make \'$a\' editable by the web server process (eg apache) then you could edit this file directly from this page';
$string['manageblocks'] = 'Blocks';
$string['managecourses'] = 'Manage courses';
$string['managedatabase'] = 'Database';
$string['managefilters'] = 'Filters';
$string['managemeta'] = 'Is this a meta course?';
$string['managemetadisabled'] = 'This is disabled because this course is already in a meta course';
$string['managemetaexplan'] = '(This means that enrolments are inherited from other courses)';
$string['managemodules'] = 'Modules';
$string['manageroles'] = 'Roles and permissions';
$string['markedthistopic'] = 'This topic is highlighted as the current topic';
$string['markthistopic'] = 'Highlight this topic as the current topic';
$string['maximumchars'] = 'Maximum of $a characters';
$string['maximumgrade'] = 'Maximum grade';
$string['maximumshort'] = 'Max';
$string['maximumupload'] = 'Maximum upload size';
$string['maxsize'] = 'Max size: $a';
$string['memberincourse'] = 'People in the course';
$string['messagebody'] = 'Message body';
$string['messagedselectedusers'] = 'Selected users have been messaged and the recipient list has been reset.';
$string['messagedselectedusersfailed'] = 'Something went wrong while messaging selected users.  Some may have received the email.';
$string['messageselect'] = 'Select this user as an email recipient';
$string['messageselectadd'] = 'Add / send message';
$string['metaaddcourse'] = 'Add this course';
$string['metaalreadycourses'] = 'Courses already assigned';
$string['metaalreadyhascourses'] = 'This meta course already has child courses.';
$string['metaalreadyhasenrolments'] = 'This course already has normal enrolments.';
$string['metaalreadyinmeta'] = 'This course is already part of a meta course.';
$string['metaassigncourses'] = 'Assign courses';
$string['metacourse'] = 'Metacourse';
$string['metanoalreadycourses'] = 'No courses already assigned';
$string['metanopotentialcourses'] = 'No courses available';
$string['metapotentialcourses'] = 'Courses available';
$string['metaremovecourse'] = 'Remove this course';
$string['migratinggrades'] = 'Migrating grades';
$string['min'] = 'min';
$string['mins'] = 'mins';
$string['minutes'] = 'minutes';
$string['miscellaneous'] = 'Miscellaneous';
$string['missingcategory'] = 'You need to choose a category';
$string['missingcity'] = 'Missing city/town';
$string['missingcountry'] = 'Missing country';
$string['missingdescription'] = 'Missing description';
$string['missingemail'] = 'Missing email address';
$string['missingfirstname'] = 'Missing given name';
$string['missingfromdisk'] = 'Missing from disk';
$string['missingfullname'] = 'Missing full name';
$string['missinglastname'] = 'Missing surname';
$string['missingname'] = 'Missing name';
$string['missingnewpassword'] = 'Missing new password';
$string['missingpassword'] = 'Missing password';
$string['missingrecaptchachallengefield'] = 'Missing reCAPTCHA challenge field';
$string['missingreqreason'] = 'Missing reason';
$string['missingshortname'] = 'Missing short name';
$string['missingshortsitename'] = 'Missing short site name';
$string['missingsitedescription'] = 'Missing site description';
$string['missingsitename'] = 'Missing site name';
$string['missingstrings'] = 'Check for untranslated words or phrases';
$string['missingstudent'] = 'Must choose something';
$string['missingsummary'] = 'Missing summary';
$string['missingteacher'] = 'Must choose something';
$string['missingurl'] = 'Missing URL';
$string['missingusername'] = 'Missing username';
$string['modified'] = 'Modified';
$string['moduledeleteconfirm'] = 'You are about to completely delete the module \'$a\'.  This will completely delete everything in the database associated with this activity module.  Are you SURE you want to continue?';
$string['moduledeletefiles'] = 'All data associated with the module \'$a->module\' has been deleted from the database.  To complete the deletion (and prevent the module re-installing itself), you should now delete this directory from your server: $a->directory';
$string['modulesetup'] = 'Setting up module tables';
$string['modulesuccess'] = '$a tables have been set up correctly';
$string['moodledocs'] = 'Moodle Docs';
$string['moodledocslink'] = 'Moodle Docs for this page';
$string['moodleversion'] = 'Moodle Version';
$string['more'] = 'more';
$string['moreinformation'] = 'More information about this error';
$string['moreprofileinfoneeded'] = 'Please tell us more about yourself';
$string['mostrecently'] = 'most recently';
$string['move'] = 'Move';
$string['movecategoryto'] = 'Move category to:';
$string['movecategorycontentto'] = 'Move into';
$string['movecontentstoanothercategory'] = 'Move contents to another category';
$string['movecourseto'] = 'Move course to:';
$string['movedown'] = 'Move down';
$string['movefilestohere'] = 'Move files to here';
$string['movefull'] = 'Move $a to this location';
$string['movehere'] = 'Move to here';
$string['moveleft'] = 'Move left';
$string['moveright'] = 'Move right';
$string['movesection'] = 'Move section $a';
$string['moveselectedcoursesto'] = 'Move selected courses to...';
$string['movetoanotherfolder'] = 'Move to another folder';
$string['moveup'] = 'Move up';
$string['msnid'] = 'MSN ID';
$string['mustchangepassword'] = 'The new password must be different than the current one';
$string['mustconfirm'] = 'You need to confirm your login';
$string['mycourses'] = 'My courses';
$string['name'] = 'Name';
$string['namelams'] = 'LAMS';
$string['namescorm'] = 'SCORM';
$string['namesocial'] = 'section';
$string['nametopics'] = 'topic';
$string['nameweeks'] = 'week';
$string['nameweekscss'] = 'week';
$string['needed'] = 'Needed';
$string['never'] = 'Never';
$string['neverdeletelogs'] = 'Never delete logs';
$string['new'] = 'New';
$string['newaccount'] = 'New account';
$string['newcourse'] = 'New course';
$string['newpassword'] = 'New password';
$string['newpasswordfromlost'] = '<strong>NOTICE:</strong> Your <strong>Current Password</strong> will have been sent to you in the <strong>second</strong> of the two emails sent as part of the lost password recovery process. Make sure you have received your replacement password before continuing with this screen.';
$string['newpasswordtext'] = 'Hi $a->firstname,

Your account password at \'$a->sitename\' has been reset
and you have been issued with a new temporary password.

Your current login information is now:
   username: $a->username
   password: $a->newpassword

Please go to this page to change your password:
   $a->link

In most mail programs, this should appear as a blue link
which you can just click on.  If that doesn\'t work,
then cut and paste the address into the address
line at the top of your web browser window.

Cheers from the \'$a->sitename\' administrator,
$a->signoff';
$string['newpicture'] = 'New picture';
$string['newsitem'] = 'news item';
$string['newsitems'] = 'news items';
$string['newsitemsnumber'] = 'News items to show';
$string['newuser'] = 'New user';
$string['newusernewpasswordsubj'] = 'New user account';
$string['newusernewpasswordtext'] = 'Hi $a->firstname,

A new account has been created for you at \'$a->sitename\'
and you have been issued with a new temporary password.

Your current login information is now:
   username: $a->username
   password: $a->newpassword
             (you will have to change your password
              when you login for the first time)

To start using \'$a->sitename\', login at
   $a->link

In most mail programs, this should appear as a blue link
which you can just click on.  If that doesn\'t work,
then cut and paste the address into the address
line at the top of your web browser window.

Cheers from the \'$a->sitename\' administrator,
$a->signoff';
$string['newusers'] = 'New users';
$string['newwindow'] = 'new window';
$string['next'] = 'Next';
$string['nextsection'] = 'Next section';
$string['no'] = 'No';
$string['nobody'] = 'Nobody';
$string['nochange'] = 'No change';
$string['nocoursesfound'] = 'No courses were found with the words \'$a\'';
$string['nocoursesyet'] = 'No courses in this category';
$string['nodstpresets'] = 'The administrator has not enabled Daylight Savings Time support.';
$string['noexistingadmins'] = 'No existing admins, this is a serious error and you should never have seen this message.';
$string['noexistingcreators'] = 'No existing creators';
$string['noexistingstudents'] = 'No existing students';
$string['noexistingteachers'] = 'No existing teachers';
$string['nofilesselected'] = 'No files have been selected to restore';
$string['nofilesyet'] = 'No files have been uploaded to your course yet';
$string['nograde'] = 'No grade';
$string['noimagesyet'] = 'No images have been uploaded to your course yet';
$string['nologsfound'] = 'No logs have been found';
$string['nomorecourses'] = 'No more matching courses could be found';
$string['nomoreidnumber'] = 'Not using an idnumber to avoid collisions';
$string['none'] = 'None';
$string['noneditingteacher'] = 'Non-editing teacher';
$string['noneditingteacherdescription'] = 'Non-editing teachers can teach in courses and grade students, but may not alter activities.';
$string['nonstandard'] = 'Non-standard';
$string['nopendingcourses'] = 'There are no courses pending approval';
$string['nopotentialadmins'] = 'No potential admins';
$string['nopotentialcreators'] = 'No potential course creators';
$string['nopotentialstudents'] = 'No potential students';
$string['nopotentialteachers'] = 'No potential teachers';
$string['norecentactivity'] = 'No recent activity';
$string['noreplybouncemessage'] = 'You have replied to a no-reply email address. If you were attempting to reply to a forum post, please instead reply using the $a forums.

Following is the content of your email:';
$string['noreplybouncesubject'] = '$a - bounced email.';
$string['noreplyname'] = 'Do not reply to this email';
$string['noresults'] = 'No results';
$string['normal'] = 'Normal';
$string['normalfilter'] = 'Normal search';
$string['nosite'] = 'Could not find site-level course';
$string['nostatstodisplay'] = 'There is no available data to display, sorry.';
$string['nostudentsfound'] = 'No $a found';
$string['nostudentsingroup'] = 'There are no students in this group yet';
$string['nostudentsyet'] = 'No students enrolled in this course yet';
$string['nosuchemail'] = 'No such email address';
$string['notavailable'] = 'Not available';
$string['noteachersyet'] = 'No teachers in this course yet';
$string['notenrollable'] = 'This course is not enrollable at the moment.';
$string['notenrolled'] = '$a is not enrolled in this course.';
$string['notenrolledprofile'] = 'This profile is not available because this user is not enrolled in this course.';
$string['noteusercannotrolldatesoncontext'] = '<strong>Note:</strong> The ability to roll dates when restoring this backup has been disabled because you lack the required permissions.';
$string['noteuserschangednonetocourse'] = '<strong>Note:</strong> Course users need to be restored when restoring user data (in activities, files or messages). This setting has been changed for you.';
$string['nothingnew'] = 'Nothing new since your last login';
$string['nothingtodisplay'] = 'Nothing to display';
$string['notice'] = 'Notice';
$string['noticenewerbackup'] = 'This backup file has been created with Moodle $a->backuprelease ($a->backupversion) and it\'s newer than your currently installed Moodle $a->serverrelease ($a->serverversion). This could cause some inconsistencies because backwards compatibility of backup files cannot be guaranteed.';
$string['notifications'] = 'Notifications';
$string['notifyloginfailuresmessage'] = '$a->time, IP: $a->ip, User: $a->info';
$string['notify'] = 'Notify';
$string['notifyloginfailuresmessageend'] = 'You can view these logs at $a/course/report/log/index.php?id=1&amp;chooselog=1&amp;modid=site_errors.';
$string['notifyloginfailuresmessagestart'] = 'Here is a list of failed login attempts at $a since you were last notified';
$string['notifyloginfailuressubject'] = '$a :: Failed logins notification';
$string['notincluded'] = 'Not included';
$string['notingroup'] = 'Sorry, but you need to be part of a group to see this activity.';
$string['notpublic'] = 'Not public!';
$string['nousersmatching'] = 'No users matching \'$a\' were found';
$string['nousersfound'] = 'No users found';
$string['nousersyet'] = 'There are no users yet';
$string['now'] = 'now';
$string['novalidcourses'] = 'No valid courses to be shown';
$string['numattempts'] = '$a failed login attempt(s)';
$string['numberweeks'] = 'Number of weeks/topics';
$string['numdays'] = '$a days';
$string['numhours'] = '$a hours';
$string['numletters'] = '$a letters';
$string['numminutes'] = '$a minutes';
$string['nummonths'] = '$a months';
$string['numseconds'] = '$a seconds';
$string['numviews'] = '$a views';
$string['numweeks'] = '$a weeks';
$string['numwords'] = '$a words';
$string['numyears'] = '$a years';
$string['ok'] = 'OK';
$string['oldpassword'] = 'Current Password';
$string['olduserdirectory'] = 'This is the OLD users directory, and is no longer needed. You may safely delete it. The files it contains have been copied to the NEW user directory.';
$string['opentoguests'] = 'Guest access';
$string['optional'] = 'optional';
$string['order'] = 'Order';
$string['other'] = 'Other';
$string['outline'] = 'Outline';
$string['outlinereport'] = 'Outline report';
$string['page'] = 'Page';
$string['pageheaderconfigablock'] = 'Configuring a block in %%fullname%%';
$string['parentcategory'] = 'Parent category';
$string['parentcoursenotfound'] = 'Parent course not found!';
$string['parentcoursenotmetacourse'] = 'Parent course not metacourse!';
$string['parentfolder'] = 'Parent folder';
$string['participants'] = 'Participants';
$string['participationratio'] = 'Participation ratio';
$string['participationreport'] = 'Participation report';
$string['password'] = 'Password';
$string['passwordchanged'] = 'Password has been changed';
$string['passwordconfirmchange'] = 'Confirm password change';
$string['passwordextlink'] = 'The following link has been provided to recover your lost password. This will take you out of Moodle.';
$string['passwordforgotten'] = 'Forgotten password';
$string['passwordforgotteninstructions'] = 'Your details must first be found in the user database. Please enter <strong>either</strong> your username or your registered email address in the appropriate box. There is no need to enter both.';
$string['passwordnohelp'] = 'No help is available to find your lost password. Please contact your Moodle administrator.';
$string['passwordrecovery'] = 'Yes, help me log in';
$string['passwordsdiffer'] = 'These passwords do not match';
$string['passwordsent'] = 'Password has been sent';
$string['passwordsenttext'] = '<p>An email has been sent to your address at $a->email.</p>
   <p><b>Please check your email for your new password</b></p>
   <p>The new password was automatically generated, so you might like to
   <a href=\"$a->link\">change it to something easier to remember</a>.</p>';
$string['pathnotexists'] = 'Path doesn\'t exist in your server!';
$string['pathslasherror'] = 'Path can\'t end with a slash!!';
$string['paymentinstant'] = 'Use the button below to pay and be enrolled within minutes!';
$string['paymentpending'] = '(<small><b><u>$a</u></b> pending</small>)';
$string['paymentrequired'] = 'This course requires a payment for entry.';
$string['payments'] = 'Payments';
$string['paymentsorry'] = 'Thank you for your payment!  Unfortunately your payment has not yet been fully processed, and you are not yet registered to enter the course \"$a->fullname\".  Please try continuing to the course in a few seconds, but if you continue to have trouble then please alert the $a->teacher or the site administrator';
$string['paymentthanks'] = 'Thank you for your payment!  You are now enrolled in your course:<br />\"$a\"';
$string['people'] = 'People';
$string['pendingrequests'] = 'Pending requests';
$string['periodending'] = 'Period ending ($a)';
$string['personal'] = 'Personal';
$string['personalprofile'] = 'Personal profile';
$string['pictureof'] = 'Picture of $a';
$string['phone'] = 'Phone';
$string['phone2'] = 'Mobile Phone';
$string['phpinfo'] = 'PHP info';
$string['pleaseclose'] = 'Please close this window now.';
$string['plugincheck'] = 'Plugins check';
$string['pluginchecknotice'] = 'The following tables show the modules, blocks and filters that have been detected in your current Moodle installation;
They indicate which plugins are standard, and which are not. All non-standard plugins should be checked and upgraded to their most recent versions
before continuing with this Moodle upgrade.';
$string['pluginsetup'] = 'Setting up plugin tables';
$string['policyaccept'] = 'I understand and agree';
$string['policyagree'] = 'You must agree to this policy to continue using this site.  Do you agree?';
$string['policyagreement'] = 'Site Policy Agreement';
$string['policyagreementclick'] = 'Link to Site Policy Agreement';
$string['popup'] = 'popup';
$string['popupwindowname'] = 'Popup window';
$string['popupwindow'] = 'Open file in new window';
$string['post'] = 'Post';
$string['posts'] = 'Posts';
$string['potentialadmins'] = 'Potential admins';
$string['potentialcreators'] = 'Potential course creators';
$string['potentialstudents'] = 'Potential students';
$string['potentialteachers'] = 'Potential teachers';
$string['preferences'] = 'Preferences';
$string['preferredlanguage'] = 'Preferred language';
$string['preferredtheme'] = 'Preferred theme';
$string['preprocessingbackupfile'] = 'Preprocessing backup file';
$string['preview'] = 'Preview';
$string['previewhtml'] = 'HTML Format Preview';
$string['previeworchoose'] = 'Preview or choose a theme';
$string['previous'] = 'Previous';
$string['previoussection'] = 'Previous section';
$string['primaryadminsetup'] = 'Setup administrator account';
$string['profile'] = 'Profile';
$string['profilenotshown'] = 'This profile description will not be shown until this person is enrolled in at least one course.';
$string['publicdirectory'] = 'Public directory';
$string['publicdirectory0'] = 'Please do not publish this site';
$string['publicdirectory1'] = 'Publish the site name only';
$string['publicdirectory2'] = 'Publish the site name with a link';
$string['publicdirectorytitle'] = 'See the current list of sites';
$string['publicsitefileswarning'] = 'Note: files placed here can be accessed by anyone';
$string['publicsitefileswarning2'] = 'Note: Files placed here can be accessed by anyone who knows (or can guess) the URL. For security reasons, it is recommended that any backup files are deleted immediately after restoring them.';
$string['publicsitefileswarning3'] = 'Note: Files placed here can be accessed by anyone who knows (or can guess) the URL. <br />For security reasons, backup files should be saved in the secure backupdata folder only.';
$string['question'] = 'Question';
$string['questionsinthequestionbank'] = 'Questions in the question bank';
$string['readinginfofrombackup'] = 'Reading info from backup';
$string['readme'] = 'README';
$string['recentactivity'] = 'Recent Activity';
$string['recentactivityreport'] = 'Full report of recent activity...';
$string['recipientslist'] = 'Recipients list';
$string['recreatedcategory'] = 'Recreated category $a';
$string['refreshingevents'] = 'Refreshing events';
$string['refresh'] = 'Refresh';
$string['registration'] = 'Moodle Registration';
$string['registrationcontact'] = 'Contact from the public';
$string['registrationcontactno'] = 'No, I do not want a contact form in the site listing';
$string['registrationcontactyes'] = 'Yes, provide a form for prospective Moodlers to contact me';
$string['registrationemail'] = 'Email notifications';
$string['registrationinfo'] = '<p>This page allows you to register your Moodle site with moodle.org.  Registration is free.
The main benefit of registering is that you will be added to a low-volume mailing list
for important notifications such as security alerts and new releases of Moodle.</p>
<p>By default, your information will be kept private, and will never be sold or passed on to anyone else.  The only
   reason for collecting this information is for support purposes, and to help build up a statistical
   picture of the Moodle community as a whole.</p>
<p>If you choose, you can allow your site name, country and URL to be added to the public list of Moodle Sites.</p>
<p>All new registrations are verified manually before they are added to the list, but once you are added you can update your registration (and your entry on the public list) at any time by resubmitting this form.</p>';
$string['registrationinfotitle'] = 'Registration Information';
$string['registrationno'] = 'No, I do not want to receive email';
$string['registrationsend'] = 'Send registration information to moodle.org';
$string['registrationyes'] = 'Yes, please notify me about important issues';
$string['reject'] = 'Reject';
$string['rejectdots'] = 'Reject...';
$string['reload'] = 'Reload';
$string['remoteappuser'] = 'Remote $a User';
$string['remove'] = 'Remove';
$string['removeadmin'] = 'Remove admin';
$string['removecreator'] = 'Remove course creator';
$string['removestudent'] = 'Remove student';
$string['removeteacher'] = 'Remove teacher';
$string['rename'] = 'Rename';
$string['renamefileto'] = 'Rename <b>$a</b> to';
$string['report'] = 'Report';
$string['reports'] = 'Reports';
$string['requestcourse'] = 'Request a course';
$string['requestedby'] = 'Requested by';
$string['requestreason'] = 'Reason for course request';
$string['required'] = 'Required';
$string['requireskey'] = 'This course requires an enrolment key';
$string['requirespayment'] = 'This course requires payment for access';
$string['reset'] = 'Reset';
$string['resetcomponent'] = 'Component';
$string['resettask'] = 'Task';
$string['resetnotimplemented'] = 'Reset not implemented';
$string['resetstatus'] = 'Status';
$string['resetcourse'] = 'Reset course';
$string['resetinfo'] = 'This page allows you to empty a course of user data, while retaining the activities and other settings.  Please be warned that by choosing items below and submitting this page you will delete your chosen user data from this course forever!';
$string['resetstartdate'] = 'Reset start date';
$string['resettodefaults'] = 'Reset to defaults';
$string['resortcoursesbyname'] = 'Re-sort courses by name';
$string['resource'] = 'Resource';
$string['resources'] = 'Resources';
$string['restore'] = 'Restore';
$string['restorecancelled'] = 'Restore cancelled';
$string['restorecannotassignroles'] = 'Restore needs to assign roles and you do not have permission to do so';
$string['restorecannotcreateorassignroles'] = 'Restore needs to create or assign roles and you do not have permission to do so';
$string['restorecannotcreateuser'] = 'Restore needs to create user \'$a\' from backup file and you do not have permission to do so';
$string['restorecannotoverrideperms'] = 'Restore needs to override permissions and you do not have permission to do so';
$string['restorecoursenow'] = 'Restore this course now!';
$string['restoredaccount'] = 'Restored account';
$string['restoredaccountinfo'] = 'This account was imported from another server and the password has been lost. To set a new password by email, please click \"Continue\"';
$string['restorefinished'] = 'Restore completed successfully';
$string['restoreto'] = 'Restore to';
$string['restoretositeadding'] = 'Warning: You are about to restore to the site front page, adding data to it!';
$string['restoretositedeleting'] = 'Warning: You are about to restore to the site front page, deleting data from it first!';
$string['restoreuserconflict'] = 'Trying to restore user \'$a\' from backup file will cause conflict';
$string['restoreuserinfofailed'] = 'The restore process has stopped because you don\'t have permission to restore user data.';
$string['restoreusersprecheck'] = 'Checking user data';
$string['restoreusersprecheckerror'] = 'Some problems were detected when checking user data';
$string['restricted'] = 'Restricted';
$string['restrictmodules'] = 'Restrict activity modules?';
$string['returningtosite'] = 'Returning to this web site?';
$string['revert'] = 'Revert';
$string['role'] = 'Role';
$string['rolemappings'] = 'Role mappings';
$string['rolerenaming'] = 'Role renaming';
$string['roles'] = 'Roles';
$string['rss'] = 'RSS';
$string['rssarticles'] = 'Number of RSS recent articles';
$string['rsserror'] = 'Error reading RSS data';
$string['rsstype'] = 'RSS feed for this activity';
$string['saveandnext'] = 'Save and show next';
$string['savechanges'] = 'Save changes';
$string['savechangesanddisplay'] = 'Save and display';
$string['savechangesandreturntocourse'] = 'Save and return to course';
$string['savedat'] = 'Saved at:';
$string['savepreferences'] = 'Save preferences';
$string['saveto'] = 'Save to';
$string['scale'] = 'Scale';
$string['scales'] = 'Scales';
$string['scalescustom'] = 'Custom scales';
$string['scalescustomcreate'] = 'Add a new scale';
$string['scalescustomno'] = 'No custom scales have been created yet';
$string['scalesstandard'] = 'Standard scales';
$string['scalestandard'] = 'Standard scale';
$string['scalestip'] = 'To create custom scales, use the \'Scales...\' link in your course administration menu.';
$string['scalestip2'] = 'To create custom scales, click the Grades link in the course administration menu, then choose Edit, Scales.';
$string['schedule'] = 'Schedule';
$string['scheduledbackupsinactive'] = 'Scheduled backups haven\'t been enabled by the site admin';
$string['scheduledbackupstatus'] = 'Scheduled backup status';
$string['screenreaderuse'] = 'Screen reader';
$string['screenreaderno'] = 'No';
$string['screenreaderyes'] = 'Yes';
$string['screenshot'] = 'Screenshot';
$string['search'] = 'Search';
$string['searchagain'] = 'Search again';
$string['searchcourses'] = 'Search courses';
$string['searchhelp'] = 'You can search for multiple words at once.<br /><br />word : find any match of this word within the text.<br />+word : only exact matching words will be found.<br />-word : don\'t include results containing this word.';
$string['searchresults'] = 'Search results';
$string['sec'] = 'sec';
$string['secondstotime172800'] = '2 days';
$string['secondstotime259200'] = '3 days';
$string['secondstotime345600'] = '4 days';
$string['secondstotime432000'] = '5 days';
$string['secondstotime518400'] = '6 days';
$string['secondstotime604800'] = '1 Week';
$string['secondstotime86400'] = '1 day';
$string['secretalreadyused'] = 'Change password confirmation link was already used, password was not changed.';
$string['secs'] = 'secs';
$string['section'] = 'Section';
$string['sections'] = 'Sections';
$string['seealsostats'] = 'See also: stats';
$string['select'] = 'Select';
$string['selectacountry'] = 'Select a country';
$string['selectall'] = 'Select all';
$string['selectdefault'] = 'Select default';
$string['selectamodule'] = 'Please select an activity module';
$string['selectednowmove'] = '$a files selected for moving. Now go into the destination folder and press \'Move files to here\'';
$string['selectnos'] = 'Select all \'no\'';
$string['selectperiod'] = 'Select period';
$string['senddetails'] = 'Send my details via email';
$string['separate'] = 'Separate';
$string['separateandconnected'] = 'Separate and Connected ways of knowing';
$string['serverlocaltime'] = 'Server\'s local time';
$string['setcategorytheme'] = 'Set Category Theme';
$string['settings'] = 'Settings';
$string['shortname'] = 'Short name';
$string['shortnamecollisionwarning'] = '[*] = This shortname is already in use by a course and will need to be changed upon approval';
$string['shortnametaken'] = 'Short name is already used for another course ($a)';
$string['shortsitename'] = 'Short name for site (eg single word)';
$string['show'] = 'Show';
$string['showactions'] = 'Show actions';
$string['showadvancedsettings'] = 'Show advanced settings';
$string['showall'] = 'Show all $a';
$string['showallcourses'] = 'Show all courses';
$string['showalltopics'] = 'Show all topics';
$string['showallusers'] = 'Show all users';
$string['showallweeks'] = 'Show all weeks';
$string['showblockcourse'] = 'Show list of courses containing block';
$string['showgrades'] = 'Show gradebook to students';
$string['showlistofcourses'] = 'Show list of courses';
$string['showmodulecourse'] = 'Show list of courses containing activity';
$string['showonly'] = 'Show only';
$string['showonlytopic'] = 'Show only topic $a';
$string['showonlyweek'] = 'Show only week $a';
$string['showperpage'] = 'Show $a per page';
$string['showrecent'] = 'Show recent activity';
$string['showreports'] = 'Show activity reports';
$string['showsettings'] = 'Show settings';
$string['showtheselogs'] = 'Show these logs';
$string['showthishelpinlanguage'] = 'Show this help in language: $a';
$string['since'] = 'Since';
$string['sincelast'] = 'since last login';
$string['site'] = 'Site';
$string['sitedefault'] = 'Site Default';
$string['siteerrors'] = 'Site errors';
$string['sitefiles'] = 'Site files';
$string['sitefilesused'] = 'Site files used in this course';
$string['sitelogs'] = 'Site logs';
$string['sitenews'] = 'Site news';
$string['sitepartlist'] = 'You do not have the required permissions to view the participants list';
$string['sitepartlist0'] = 'You must be a site teacher to be allowed to see the site participants list';
$string['sitepartlist1'] = 'You must be a teacher to be allowed to see the site participants list';
$string['sites'] = 'Sites';
$string['sitesection'] = 'Include a topic section';
$string['sitesettings'] = 'Site settings';
$string['siteteachers'] = 'Site teachers';
$string['size'] = 'Size';
$string['sizeb'] = 'bytes';
$string['sizegb'] = 'GB';
$string['sizekb'] = 'KB';
$string['sizemb'] = 'MB';
$string['skipped'] = 'Skipped';
$string['skypeid'] = 'Skype ID';
$string['socialheadline'] = 'Social forum - latest topics';
$string['someallowguest'] = 'Some courses may allow guest access';
$string['someerrorswerefound'] = 'Some information was missing or incorrect. Look below for details.';
$string['sortby'] = 'Sort by';
$string['sourcerole'] = 'Source role';
$string['specifyname'] = 'You must specify a name.';
$string['standard'] = 'Standard';
$string['starpending'] = '([*] = course pending approval)';
$string['startdate'] = 'Course start date';
$string['startsignup'] = 'Create new account';
$string['state'] = 'State/Province';
$string['statistics'] = 'Statistics';
$string['statisticsgraph'] = 'Statistics graph';
$string['stats'] = 'Statistics';
$string['statslogins'] = 'Logins';
$string['statsmodedetailed'] = 'Detailed (user) view';
$string['statsmodegeneral'] = 'General view';
$string['statsnodata'] = 'There is no available data for that combination of course and time period.';
$string['statsnodatauser'] = 'There is no available data for that combination of course, user and time period.';
$string['statsoff'] = 'Statistics is not currently enabled';
$string['statsreads'] = 'Views';
$string['statsreport1'] = 'Logins';
$string['statsreport10'] = 'User activity';
$string['statsreport11'] = 'Most active courses';
$string['statsreport12'] = 'Most active courses (weighted)';
$string['statsreport13'] = 'Most participatory courses (enrolments)';
$string['statsreport14'] = 'Most participatory courses (views/posts)';
$string['statsreport2'] = 'Views (all roles)';
$string['statsreport3'] = 'Posts (all roles)';
$string['statsreport4'] = 'All activity (all roles)';
$string['statsreport5'] = 'All activity (views and posts)';
$string['statsreport7'] = 'User activity (views and posts)';
$string['statsreport8'] = 'All User activity';
$string['statsreport9'] = 'Logins (site course)';
$string['statsreportactivity'] = 'All activity (all roles)';
$string['statsreportactivitybyrole'] = 'All activity (views and posts)';
$string['statsreportforuser'] = 'for';
$string['statsreportlogins'] = 'Logins';
$string['statsreportreads'] = 'Views (all roles)';
$string['statsreporttype'] = 'Report type';
$string['statsreportwrites'] = 'Posts (all roles)';
$string['statsstudentactivity'] = 'Student activity';
$string['statsstudentreads'] = 'Student views';
$string['statsstudentwrites'] = 'Student posts';
$string['statsteacheractivity'] = 'Teacher activity';
$string['statsteacherreads'] = 'Teacher views';
$string['statsteacherwrites'] = 'Teacher posts';
$string['statstimeperiod'] = 'Time period - last:';
$string['statsuniquelogins'] = 'Unique logins';
$string['statsuseractivity'] = 'All activity';
$string['statsuserlogins'] = 'Logins';
$string['statsuserreads'] = 'Views';
$string['statsuserwrites'] = 'Posts';
$string['statswrites'] = 'Posts';
$string['status'] = 'Status';
$string['strftimedate'] = '%%d %%B %%Y';
$string['strftimedateshort'] = '%%d %%B';
$string['strftimedatetime'] = '%%d %%B %%Y, %%I:%%M %%p';
$string['strftimedatetimeshort'] = '%%d/%%m/%%Y %%H:%%M';
$string['strftimedaydate'] = '%%A, %%d %%B %%Y';
$string['strftimedaydatetime'] = '%%A, %%d %%B %%Y, %%I:%%M %%p';
$string['strftimedayshort'] = '%%A, %%d %%B';
$string['strftimedaytime'] = '%%a, %%H:%%M';
$string['strftimemonthyear'] = '%%B %%Y';
$string['strftimerecent'] = '%%d %%b, %%H:%%M';
$string['strftimerecentfull'] = '%%a, %%d %%b %%Y, %%I:%%M %%p';
$string['strftimetime'] = '%%I:%%M %%p';
$string['stringsnotset'] = 'The following strings are not defined in $a';
$string['studentnotallowed'] = 'Sorry, but you can not enter this course as \'$a\'';
$string['students'] = 'Students';
$string['studentsandteachers'] = 'Students and teachers';
$string['studentviewoff'] = 'Turn student view off';
$string['studentviewon'] = 'Turn student view on';
$string['subcategories'] = 'Sub-categories';
$string['submit'] = 'Submit';
$string['success'] = 'Success';
$string['summary'] = 'Summary';
$string['summaryof'] = 'Summary of $a';
$string['supplyinfo'] = 'More details';
$string['switchrolereturn'] = 'Return to my normal role';
$string['switchroleto'] = 'Switch role to...';
$string['tag'] = 'Tag';
$string['tagalready'] = 'This tag already exists';
$string['tagmanagement'] = 'Add/delete tags ...';
$string['tags'] = 'Tags';
$string['targetrole'] = 'Target role';
$string['teacheronly'] = 'for the $a only';
$string['teacherroles'] = '$a roles';
$string['teachers'] = 'Teachers';
$string['textediting'] = 'When editing text';
$string['texteditor'] = 'Use standard web forms';
$string['textformat'] = 'Plain text format';
$string['thanks'] = 'Thanks';
$string['theme'] = 'Theme';
$string['themes'] = 'Themes';
$string['themesaved'] = 'New theme saved';
$string['thereareno'] = 'There are no $a in this course';
$string['thiscategorycontains'] = 'This category contains';
$string['thischarset'] = 'UTF-8';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'English';
$string['time'] = 'Time';
$string['timezone'] = 'Timezone';
$string['to'] = 'To';
$string['today'] = 'Today';
$string['todaylogs'] = 'Today\'s logs';
$string['toeveryone'] = 'to everyone';
$string['toomanybounces'] = 'That email address has had too many bounces. You <b>must</b> change it to continue.';
$string['toomanytoshow'] = 'There are too many users to show.';
$string['toonly'] = 'to $a only';
$string['top'] = 'Top';
$string['topic'] = 'Topic';
$string['topichide'] = 'Hide this topic from $a';
$string['topicoutline'] = 'Topic outline';
$string['topicshow'] = 'Show this topic to $a';
$string['total'] = 'Total';
$string['trackforums'] = 'Forum tracking';
$string['trackforumsno'] = 'No: don\'t keep track of posts I have seen';
$string['trackforumsyes'] = 'Yes: highlight new posts for me';
$string['trysearching'] = 'Try searching instead.';
$string['turneditingoff'] = 'Turn editing off';
$string['turneditingon'] = 'Turn editing on';
$string['undecided'] = 'Undecided';
$string['unenrol'] = 'Unenrol';
$string['unenrolroleusers'] = 'Unenrol users';
$string['unenrolallstudents'] = 'Unenrol all students';
$string['unenrolallstudentssure'] = 'Are you sure you want to completely unenrol all students from this course?';
$string['unenrolme'] = 'Unenrol me from $a';
$string['unenrolsure'] = 'Are you sure you want to unenrol $a from this course?';
$string['unfinished'] = 'Unfinished';
$string['unknowncategory'] = 'Unknown category';
$string['unlimited'] = 'Unlimited';
$string['unpacking'] = 'Unpacking $a';
$string['unsafepassword'] = 'Unsafe password - try something else';
$string['untilcomplete'] = 'Until complete';
$string['unusedaccounts'] = 'Accounts unused for more than $a days are automatically unenrolled';
$string['unzip'] = 'Unzip';
$string['unzippingbackup'] = 'Unzipping backup';
$string['up'] = 'Up';
$string['update'] = 'Update';
$string['updated'] = 'Updated $a';
$string['updatemymoodleoff'] = 'Normal mode';
$string['updatemymoodleon'] = 'Edit this page';
$string['updatemyprofile'] = 'Update profile';
$string['updatesevery'] = 'Updates every $a seconds';
$string['updatethis'] = 'Update this $a';
$string['updatethiscourse'] = 'Update this course';
$string['updatinga'] = 'Updating: $a';
$string['updatingain'] = 'Updating $a->what in $a->in';
$string['upload'] = 'Upload';
$string['uploadafile'] = 'Upload a file';
$string['uploadcantwrite'] = 'Failed to write file to disk';
$string['uploadedfile'] = 'File uploaded successfully';
$string['uploadedfileto'] = 'Uploaded $a->file to $a->directory';
$string['uploadedfiletoobig'] = 'Sorry, but that file is too big (limit is $a bytes)';
$string['uploadextension'] = 'File upload stopped by extension';
$string['uploadfailednotrecovering'] = 'Your file upload has failed because there was a problem with one of the files, $a->name.<br /> Here is a log of the problems:<br />$a->problem<br />Not recovering.';
$string['uploadfilelog'] = 'Upload log for file $a';
$string['uploadformlimit'] = 'Uploaded file exceeded the maximum size limit set by the form';
$string['uploadlabel'] = 'Title:';
$string['uploadnofilefound'] = 'No file was found - are you sure you selected one to upload?';
$string['uploadnotallowed'] = 'Uploads are not allowed';
$string['uploadnotempdir'] = 'Missing a temporary folder';
$string['uploadoldfilesdeleted'] = 'The old file(s) in your upload area have been deleted';
$string['uploadpartialfile'] = 'File was only partially uploaded';
$string['uploadproblem'] = 'An unknown problem occurred while uploading the file \'$a\' (perhaps it was too large?)';
$string['uploadrenamedchars'] = 'File was renamed from $a->oldname to $a->newname because of invalid characters.';
$string['uploadrenamedcollision'] = 'File was renamed from $a->oldname to $a->newname because there was a filename conflict.';
$string['uploadserverlimit'] = 'Uploaded file exceeded the maximum size limit set by the server';
$string['uploadthisfile'] = 'Upload this file';
$string['uploadusers'] = 'Upload users';
$string['used'] = 'Used';
$string['usedinnplaces'] = 'Used in $a places';
$string['usemessageform'] = 'or use the form below to send a message to the selected students';
$string['user'] = 'User';
$string['userconfirmed'] = 'Confirmed $a';
$string['userdata'] = 'User Data';
$string['userdeleted'] = 'This user account has been deleted';
$string['userdescription'] = 'Description';
$string['userfiles'] = 'User Files';
$string['userlist'] = 'User list';
$string['username'] = 'Username';
$string['usernameemailmatch'] = 'The username and email address do not relate to the same user';
$string['usernameoremail'] = 'Enter either username or email address';
$string['usernameexists'] = 'This username already exists, choose another';
$string['usernamelowercase'] = 'Only lowercase letters allowed';
$string['usernamenotfound'] = 'The username was not found in the database';
$string['usernotconfirmed'] = 'Could not confirm $a';
$string['userpic'] = 'User picture';
$string['userprofilefor'] = 'User profile for $a';
$string['users'] = 'Users';
$string['usersnew'] = 'New users';
$string['usersnoaccesssince'] = 'Inactive for more than';
$string['userswithfiles'] = 'Users with files';
$string['userzones'] = 'User zones';
$string['usethiscourse'] = 'Use this course';
$string['usingexistingcourse'] = 'Using existing course';
$string['valuealreadyused'] = 'This value has already been used.';
$string['version'] = 'Version';
$string['view'] = 'View';
$string['views'] = 'Views';
$string['viewsolution'] = 'view solution';
$string['virusfound'] = 'Attention administrator! Clam AV has found a virus in a file uploaded by $a->user for the course $a->course. Here is the output of clamscan:';
$string['virusfoundlater'] = 'A file you uploaded on $a->date with the filename $a->filename for the course $a->course has since been found to contain a virus.  Here is a summary of what has happened to your file:

$a->action

If this was submitted work, you may want to resubmit it so that your tutor can see it.';
$string['virusfoundlateradmin'] = 'Attention administrator! A file that was uploaded on $a->date with the filename $a->filename for the course $a->course by the user $a->user has since been found to contain a virus.  Here is a summary of what has happened to the file:

$a->action

The user has also been notified.';
$string['virusfoundlateradminnolog'] = 'Attention administrator! A file that was uploaded with the filename $a->filename has since been found to contain a virus. Moodle was unable to resolve this file back to the user that originally uploaded it.

Here is a summary of what has happened to the file:

$a->action';
$string['virusfoundsubject'] = '$a: Virus found!';
$string['virusfounduser'] = 'The file you have uploaded, $a->filename, has been scanned by a virus checker and found to be infected! Your file upload was NOT successful.';
$string['virusplaceholder'] = 'This file that has been uploaded was found to contain a virus and has been moved or delted and the user notified.';
$string['visible'] = 'Visible';
$string['visibletostudents'] = 'Visible to $a';
$string['warningdeleteresource'] = 'Warning: $a is referred in a resource. Would you like to update the resource?';
$string['webpage'] = 'Web page';
$string['week'] = 'Week';
$string['weekhide'] = 'Hide this week from $a';
$string['weeklyoutline'] = 'Weekly outline';
$string['weekshow'] = 'Show this week to $a';
$string['welcometocourse'] = 'Welcome to $a';
$string['welcometocoursetext'] = 'Welcome to $a->coursename!

If you have not done so already, you should edit your profile page so that we can learn more about you:

  $a->profileurl';
$string['whattocallzip'] = 'What do you want to call the zip file?';
$string['whattodo'] = 'What to do';
$string['withchosenfiles'] = 'With chosen files';
$string['withoutuserdata'] = 'without user data';
$string['withselectedusers'] = 'With selected users...';
$string['withuserdata'] = 'with user data';
$string['wordforstudent'] = 'Your word for Student';
$string['wordforstudenteg'] = 'eg Student, Participant etc';
$string['wordforstudents'] = 'Your word for Students';
$string['wordforstudentseg'] = 'eg Students, Participants etc';
$string['wordforteacher'] = 'Your word for Teacher';
$string['wordforteachereg'] = 'eg Teacher, Tutor, Facilitator etc';
$string['wordforteachers'] = 'Your word for Teachers';
$string['wordforteacherseg'] = 'eg Teachers, Tutors, Facilitators etc';
$string['writingblogsinfo'] = 'Writing blogs info';
$string['writingcategoriesandquestions'] = 'Writing categories and questions';
$string['writingcoursedata'] = 'Writing course data';
$string['writingeventsinfo'] = 'Writing events info';
$string['writinggeneralinfo'] = 'Writing general info';
$string['writinggradebookinfo'] = 'Writing gradebook info';
$string['writinggroupsinfo'] = 'Writing groups info';
$string['writinggroupingsinfo'] = 'Writing groupings info';
$string['writinggroupingsgroupsinfo'] = 'Writing groupings-groups info';
$string['writingheader'] = 'Writing header';
$string['writingloginfo'] = 'Writing logs info';
$string['writingmessagesinfo'] = 'Writing messages info';
$string['writingmoduleinfo'] = 'Writing modules info';
$string['writingscalesinfo'] = 'Writing scales info';
$string['writinguserinfo'] = 'Writing users info';
$string['wrongpassword'] = 'Incorrect password for this username';
$string['xmldbeditor'] = 'XMLDB editor';
$string['yahooid'] = 'Yahoo ID';
$string['year'] = 'year';
$string['years'] = 'years';
$string['yes'] = 'Yes';
$string['youareabouttocreatezip'] = 'You are about to create a zip file containing';
$string['youaregoingtorestorefrom'] = 'You are about to start the restore process for';
$string['youneedtoenrol'] = 'To perform that action you need to enrol in this course.';
$string['yourlastlogin'] = 'Your last login was';
$string['yourself'] = 'yourself';
$string['yourteacher'] = 'your $a';
$string['zippingbackup'] = 'Zipping backup';

$string['authenticationplugins'] = 'Authentication Plugins';
$string['chooseauthmethod'] = 'Choose authentication plugin';
$string['nocourses'] = 'No courses';
$string['requestedcourses'] = 'Requested courses';
?>
